<p align="center">
    <img width="50%" alt="logo-kiso" src="https://github.com/user-attachments/assets/15e0777c-6305-4783-9a65-cdfabfdd52dc" />
</p>

![License](https://img.shields.io/pypi/l/kiso.svg?logo=apache&color=blue&label=License)
![Latest](https://img.shields.io/pypi/v/kiso.svg?label=Latest)
![Python Versions](https://img.shields.io/pypi/pyversions/kiso.svg?logo=python)
![PyPi Downloads](https://img.shields.io/pypi/dm/kiso?logo=pypi&color=green&label=PyPI%20Downloads)
![Code Style](https://img.shields.io/badge/Code%20Style-black-blue)
![Contributors](https://img.shields.io/github/contributors-anon/pegasus-isi/kiso?color=green&label=Contributors)

Kiso is an experiment management platform to enable the execution of experiments defined as Pegasus workflows on a variety of computing infrastructures.

<!-- - [Introduction](docs/introduction.md) -->

- [Getting Started](docs/getting-started.md)
- [Experiment Configuration](docs/experiment-configuration.rst)

# References

- [Pegasus Workflow Management System](https://pegasus.isi.edu)
- [EnOSlib](https://discovery.gitlabpages.inria.fr/enoslib/)
- [Chameleon Cloud](https://www.chameleoncloud.org)
- [FABRIC](https://portal.fabric-testbed.net)

# Funding

Kiso is funded by National Science Foundation (NSF) under award [2403051](https://www.nsf.gov/awardsearch/showAward?AWD_ID=2403051).
